/* -*- c++ -*- */
/*
 * gr-satnogs: SatNOGS GNU Radio Out-Of-Tree Module
 *
 *  Copyright (C) 2016, Libre Space Foundation <http://librespacefoundation.org/>
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#pragma once

namespace gr {
namespace satnogs {

class config
{
public:
    // clang-format off
    static constexpr short int gnuradio_major = 3;
    static constexpr short int gnuradio_minor = 10;
    static constexpr short int gnuradio_patch = 5;
    static constexpr short int gnuradio_tweak = 1;
    // clang-format on

    /**
     * @brief Returns a numerical representation of a given version in the form
     * major.minor.patch. This can be used to compare easily different versions
     * @param T an integral type
     * @param major the major version
     * @param minor the minor version
     * @param patch the patch version
     * @param tweak the tweak version
     * @return constexpr size_t a numerical representation of a version
     */
    template <class T, std::enable_if_t<std::is_integral_v<T>, bool> = true>
    static constexpr size_t gnuradio_version_num(T major, T minor, T patch, T tweak)
    {
        return (static_cast<size_t>(major) << 24) + (static_cast<size_t>(minor) << 16) +
               (static_cast<size_t>(patch) << 8) + patch;
    }
};

} // namespace satnogs
} // namespace gr
